@@ -41,7 +41,7 @@ class Q_DECL_HIDDEN Output::Private
         connected(false),
         enabled(false),
         primary(false),
-        edid(0)
+        edid(nullptr)
     {}
 
     Private(const Private &other):
@@ -108,7 +108,7 @@ bool Output::Private::compareModeList(const ModeList& before, const ModeList &af
         if (mb->size() != ma->size()) {
             return false;
         }
-        if (mb->refreshRate() != ma->refreshRate()) {
+        if (!qFuzzyCompare(mb->refreshRate(), ma->refreshRate())) {
             return false;
         }
         if (mb->name() != ma->name()) {
@@ -142,14 +142,14 @@ QString Output::Private::biggestMode(const ModeList& modes) const
     }
 
     if (!biggest) {
-        return 0;
+        return QString();
     }
 
     return biggest->id();
 }
 
 Output::Output()
- : QObject(0)
+ : QObject(nullptr)
  , d(new Private())
 {
 
@@ -387,7 +387,7 @@ qreal Output::scale() const
 
 void Output::setScale(qreal factor)
 {
-    if (d->scale == factor) {
+    if (qFuzzyCompare(d->scale, factor)) {
         return;
     }
     d->scale = factor;
@@ -460,7 +460,7 @@ void Output::setClones(QList<int> outputlist)
 
 void Output::setEdid(const QByteArray& rawData)
 {
-    Q_ASSERT(d->edid == 0);
+    Q_ASSERT(d->edid.isNull());
     d->edid = new Edid(rawData);
 }
 
@@ -527,7 +527,7 @@ void Output::apply(const OutputPtr& other)
         changes << &Output::rotationChanged;
         setRotation(other->d->rotation);
     }
-    if (d->scale != other->d->scale) {
+    if (!qFuzzyCompare(d->scale, other->d->scale)) {
         changes << &Output::scaleChanged;
         setScale(other->d->scale);
     }
@@ -584,6 +584,7 @@ QDebug operator<<(QDebug dbg, const KScreen::OutputPtr &output)
                                   << output->name()
                                   << (output->isConnected() ? "connected" : "disconnected")
                                   << (output->isEnabled() ? "enabled" : "disabled")
+                                  << (output->isPrimary() ? "primary" : "")
                                   << "pos:" << output->pos() << "res:" << output->size()
                                   << "modeId:" << output->currentModeId()
                                   << "scale:" << output->scale()
